@@ -4,13 +4,12 @@
 #   Driver module that encapsulates the details of formatting a LaTeX document
 #
 # AUTHOR
-#   Chris Travers <chris.travers@gmail.com>  (current maintainer)
+#   Andrew Ford <andrew@ford-mason.co.uk>  (current maintainer)
 #
 # COPYRIGHT
-#   Copyright (C) 2014  Chris Travers.  
-#   Copyright (C) 2009-2013 Ford & Mason Ltd.  
-#   Copyright (C) 2006-2007 Andrew Ford.  
-#   Portions Copyright (C) 1996-2006 Andy Wardley.  
+#   Copyright (C) 2009-2013 Ford & Mason Ltd.  All Rights Reserved.
+#   Copyright (C) 2006-2007 Andrew Ford.  All Rights Reserved.
+#   Portions Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
@@ -21,9 +20,7 @@ package LaTeX::Driver;
 use strict;
 use warnings;
 
-use 5.008005;
-
-use parent 'Class::Accessor';
+use base 'Class::Accessor';
 use Cwd;                                # from PathTools
 use English qw( -no_match_vars );       # standard Perl class
 use Exception::Class ( 'LaTeX::Driver::Exception' );
@@ -34,11 +31,15 @@ use File::Slurp;
 use File::Spec;                         # from PathTools
 use IO::File;                           # from IO
 use Readonly;
-use File::pushd;                        # temporary cwd changes
+
+BEGIN {
+    require IPC::ShellCmd
+        unless $OSNAME eq 'MSWin32';
+}
 
 Readonly our $DEFAULT_MAXRUNS => 10;
 
-our $VERSION = "0.20";
+our $VERSION = 0.20_02;
 
 __PACKAGE__->mk_accessors( qw( basename basedir basepath options
                                source output tmpdir format timeout stderr
@@ -337,7 +338,7 @@ sub run_latex {
 
     my $basename = $self->basename;
     my $exitcode = $self->run_command($self->formatter =>
-                                      "\\nonstopmode\\def\\TTLATEX{1}\\input{./$basename}");
+                                      "\\nonstopmode\\def\\TTLATEX{1}\\input{$basename}");
 
     # If an error occurred attempt to extract the interesting lines
     # from the log file.  Even without errors the log file may contain
@@ -665,22 +666,28 @@ sub run_command {
 
     $envvars ||= "TEXINPUTS";
     $envvars = [ $envvars ] unless ref $envvars;
+    local(@ENV{@{$envvars}}) = map { $self->texinputs_path } @{$envvars};
     $self->stats->{runs}{$progname}++;
     debug("running '$program $args'") if $DEBUG;
-    my $cwd = pushd($dir);
 
     # Format the command appropriately for our O/S
 
     my $exit_status;
     if ($OSNAME eq 'MSWin32') {
         $args = join(' ', @$args);
-        $cmd  = "cmd /c \"$program $args\"";
+        $cmd  = "cmd /c \"cd $dir && $program $args\"";
         $exit_status = system($cmd);
     }
     else {
-        local(@ENV{@{$envvars}}) = map { $self->texinputs_path } @{$envvars};
         $args = "'$args'" if $args =~ / \\ /mx;
-        $exit_status = system($program, @$args);
+        my $isc = IPC::ShellCmd->new([$program, @$args])
+            ->working_dir($dir)
+            ->run;
+        $isc->add_timers($self->timeout, 'TERM')
+            if $self->timeout;
+        $self->{stderr} .= $isc->stderr
+            if $self->{capture_stderr};
+        $exit_status = $isc->status;
     }
 
     return $exit_status;
@@ -820,7 +827,7 @@ LaTeX::Driver - Latex driver
 
 =head1 VERSION
 
-This document describes version 0.20 of C<LaTeX::Driver>.
+This document describes version 0.08 of C<LaTeX::Driver>.
 
 =head1 SYNOPSIS
 
